@@ -58,7 +58,7 @@ class Exceptions:
 
 class FISClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -67,8 +67,8 @@ class FISClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_experiment_template(
@@ -82,14 +82,14 @@ class FISClient:
         tags: Dict[str, str] = None,
     ) -> CreateExperimentTemplateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.create_experiment_template)
-        [Show boto3-stubs documentation](./client.md#create-experiment-template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.create_experiment_template)
+        [Show boto3-stubs documentation](./client.md#create_experiment_template)
         """
 
     def delete_experiment_template(self, id: str) -> DeleteExperimentTemplateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.delete_experiment_template)
-        [Show boto3-stubs documentation](./client.md#delete-experiment-template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.delete_experiment_template)
+        [Show boto3-stubs documentation](./client.md#delete_experiment_template)
         """
 
     def generate_presigned_url(
@@ -100,82 +100,82 @@ class FISClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_action(self, id: str) -> GetActionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.get_action)
-        [Show boto3-stubs documentation](./client.md#get-action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.get_action)
+        [Show boto3-stubs documentation](./client.md#get_action)
         """
 
     def get_experiment(self, id: str) -> GetExperimentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.get_experiment)
-        [Show boto3-stubs documentation](./client.md#get-experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.get_experiment)
+        [Show boto3-stubs documentation](./client.md#get_experiment)
         """
 
     def get_experiment_template(self, id: str) -> GetExperimentTemplateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.get_experiment_template)
-        [Show boto3-stubs documentation](./client.md#get-experiment-template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.get_experiment_template)
+        [Show boto3-stubs documentation](./client.md#get_experiment_template)
         """
 
     def list_actions(
         self, maxResults: int = None, nextToken: str = None
     ) -> ListActionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.list_actions)
-        [Show boto3-stubs documentation](./client.md#list-actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.list_actions)
+        [Show boto3-stubs documentation](./client.md#list_actions)
         """
 
     def list_experiment_templates(
         self, maxResults: int = None, nextToken: str = None
     ) -> ListExperimentTemplatesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.list_experiment_templates)
-        [Show boto3-stubs documentation](./client.md#list-experiment-templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.list_experiment_templates)
+        [Show boto3-stubs documentation](./client.md#list_experiment_templates)
         """
 
     def list_experiments(
         self, maxResults: int = None, nextToken: str = None
     ) -> ListExperimentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.list_experiments)
-        [Show boto3-stubs documentation](./client.md#list-experiments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.list_experiments)
+        [Show boto3-stubs documentation](./client.md#list_experiments)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def start_experiment(
         self, clientToken: str, experimentTemplateId: str, tags: Dict[str, str] = None
     ) -> StartExperimentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.start_experiment)
-        [Show boto3-stubs documentation](./client.md#start-experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.start_experiment)
+        [Show boto3-stubs documentation](./client.md#start_experiment)
         """
 
     def stop_experiment(self, id: str) -> StopExperimentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.stop_experiment)
-        [Show boto3-stubs documentation](./client.md#stop-experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.stop_experiment)
+        [Show boto3-stubs documentation](./client.md#stop_experiment)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str] = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_experiment_template(
@@ -188,6 +188,6 @@ class FISClient:
         roleArn: str = None,
     ) -> UpdateExperimentTemplateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/fis.html#FIS.Client.update_experiment_template)
-        [Show boto3-stubs documentation](./client.md#update-experiment-template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/fis.html#FIS.Client.update_experiment_template)
+        [Show boto3-stubs documentation](./client.md#update_experiment_template)
         """
