@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-from .literals import ExperimentActionStatus, ExperimentStatus
+from .literals import ExperimentActionStatusType, ExperimentStatusType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -194,7 +194,7 @@ DeleteExperimentTemplateResponseTypeDef = TypedDict(
 ExperimentActionStateTypeDef = TypedDict(
     "ExperimentActionStateTypeDef",
     {
-        "status": ExperimentActionStatus,
+        "status": ExperimentActionStatusType,
         "reason": str,
     },
     total=False,
@@ -216,7 +216,7 @@ ExperimentActionTypeDef = TypedDict(
 ExperimentStateTypeDef = TypedDict(
     "ExperimentStateTypeDef",
     {
-        "status": ExperimentStatus,
+        "status": ExperimentStatusType,
         "reason": str,
     },
     total=False,
